@@ -3,6 +3,9 @@
 import discord
 from discord.ext import commands
 from discord import app_commands
+from discord.ext.commands import Context
+import pydisadm
+from pydisadm.bot.update_adm_modal import UpdateAdmModal
 
 from pydisadm.bot.utils import check_allowed_channel, text_channels_with_send_permission
 from pydisadm.configuration import Configuration
@@ -21,6 +24,10 @@ class Adm(commands.GroupCog):
         await interaction.response.defer(thinking=True)
 
         (tier_list, generated_at) = self.controller.generate_tier_list()
+        if generated_at is None:
+            await interaction.followup.send('😥 No ADM data...')
+            return
+
         timestamp = convert_to_local_timestamp(generated_at)
 
         file_name = "adm_tier_list.txt"
@@ -47,7 +54,7 @@ class Adm(commands.GroupCog):
             )
             self.controller.delete_file(file_name)
         else:
-            await interaction.followup.send("No data (╯°□°）╯︵ ┻━┻")
+            await interaction.followup.send('😥 No ADM data...')
 
     async def update_adm(self, interaction: discord.Interaction, system_name: str, adm: float):
         """Update ADM for system"""
@@ -65,13 +72,16 @@ class Adm(commands.GroupCog):
     @app_commands.command(description='Recommend where to raise ADM')
     async def recommend(self, interaction: discord.Interaction):
         """Command recommending which system to raise ADMs"""
-        if not check_allowed_channel(interaction.channel, self.configuration.discord_channel):
+        if not check_allowed_channel(interaction.channel, self.configuration.discord['channel']):
             await interaction.response.send_message('Not allowed in this channel.', ephemeral=True)
             return
 
         await interaction.response.defer()
 
         recommended_system = self.controller.get_recommended_system()
+        if recommended_system is None:
+            await interaction.followup.send('😥 No ADM data...')
+            return
 
         system = recommended_system['solarSystemName']
         region = recommended_system['regionName']
@@ -81,7 +91,7 @@ class Adm(commands.GroupCog):
     @app_commands.command(description='Posts a summary of all system ADM levels')
     async def summary(self, interaction: discord.Interaction):
         """Command posting a summary of ADMs"""
-        if not check_allowed_channel(interaction.channel, self.configuration.discord_channel):
+        if not check_allowed_channel(interaction.channel, self.configuration.discord['channel']):
             await interaction.response.send_message('Not allowed in this channel.', ephemeral=True)
             return
 
@@ -90,7 +100,7 @@ class Adm(commands.GroupCog):
     @app_commands.command(description='Posts a CSV file of all system ADM levels')
     async def csv(self, interaction: discord.Interaction):
         """Command posting a CSV file of ADMs"""
-        if not check_allowed_channel(interaction.channel, self.configuration.discord_channel):
+        if not check_allowed_channel(interaction.channel, self.configuration.discord['channel']):
             await interaction.response.send_message('Not allowed in this channel.', ephemeral=True)
             return
 
@@ -105,7 +115,7 @@ class Adm(commands.GroupCog):
     @app_commands.describe(where='The system, constellation, or region to graph.')
     async def history(self, interaction: discord.Interaction, where: str):
         """Command posting a graph of ADM history"""
-        if not check_allowed_channel(interaction.channel, self.configuration.discord_channel):
+        if not check_allowed_channel(interaction.channel, self.configuration.discord['channel']):
             await interaction.response.send_message('Not allowed in this channel.', ephemeral=True)
             return
 
@@ -114,7 +124,7 @@ class Adm(commands.GroupCog):
     @app_commands.command(description='Manually refresh all ADM data.')
     async def refresh(self, interaction: discord.Interaction):
         """Command to manually refresh ADM data"""
-        if not check_allowed_channel(interaction.channel, self.configuration.discord_channel):
+        if not check_allowed_channel(interaction.channel, self.configuration.discord['channel']):
             await interaction.response.send_message('Not allowed in this channel.', ephemeral=True)
             return
 
@@ -123,23 +133,45 @@ class Adm(commands.GroupCog):
         await interaction.followup.send("ADM data manually refreshed 🦀")
 
     @app_commands.command(description='Manually update ADM of system.')
-    async def update(self, interaction: discord.Interaction, system_name: str, adm: str):
+    @app_commands.describe(system_name='Which system to update ADM')
+    async def update(self, interaction: discord.Interaction, system_name: str):
         """Command to manually update ADM for system"""
-        if not check_allowed_channel(interaction.channel, self.configuration.discord_channel):
+        if not check_allowed_channel(interaction.channel, self.configuration.discord['channel']):
             await interaction.response.send_message('Not allowed in this channel.', ephemeral=True)
             return
 
-        await self.update_adm(interaction, system_name, float(adm))
+        await interaction.response.send_modal(UpdateAdmModal(system_name, self.controller))
 
     @commands.Cog.listener()
     async def on_ready(self):
         """cog on_ready event callback"""
         channels = text_channels_with_send_permission(self.bot)
 
-        await self.bot.tree.sync()
-
         valid_channels = [
-            channel for channel in channels if channel.name == self.configuration.discord_channel]
+            channel for channel in channels if channel.name == self.configuration.discord['channel']
+        ]
+
+        embed = discord.Embed(title=f'🦀 ADM Bot v{pydisadm.__version__}')
+        embed.add_field(name='Summary', value='/adm summary')
+        embed.add_field(name='CSV', value='/adm csv')
+        embed.add_field(name='History', value='/adm history <name>')
+        embed.add_field(name='Update', value='/adm update <system>')
+        embed.add_field(name='Recommend', value='/adm recommend')
+        embed.add_field(name='Refresh', value='/adm refresh')
+        embed.add_field(name='Source', value='[github](https://github.com/agelito/adm-bot)')
 
         for channel in valid_channels:
-            await channel.send('=== ADM Bot is started 🦀 ===')
+            await channel.send(embed=embed)
+
+    @commands.command(pass_context=True)
+    async def adm_sync_commands(self, ctx: Context):
+        """synchronize slash commands"""
+
+        if self.configuration.discord['guild_id']:
+            guild = discord.Object(id=self.configuration.discord['guild_id'])
+            self.bot.tree.copy_global_to(guild=guild)
+            await self.bot.tree.sync(guild=guild)
+        else:
+            await self.bot.tree.sync()
+
+        await ctx.send('Synchronized bot commands.')
