@@ -5,15 +5,16 @@ import pandas as pd
 from tabulate import tabulate
 
 from pydisadm.configuration import Configuration
-from pydisadm.services.database import Database
+from pydisadm.services.database_sqlite import DatabaseSqlite
 from pydisadm.services.esi import sovereignty_structures
+from pydisadm.utils.adm_utils import adm_from_index
 from pydisadm.utils.plot_utils import plot_adm_history_of_systems, plot_save_to_file
 
 
 class AdmController:
     """Controller implementation for ADM operations"""
 
-    def __init__(self, configuration: Configuration, database: Database):
+    def __init__(self, configuration: Configuration, database: DatabaseSqlite):
         self.configuration = configuration
         self.database = database
 
@@ -57,7 +58,12 @@ class AdmController:
 
         generated_at = self.database.select_most_recent_row()
 
-        return (table, generated_at['created_at'][0])
+        if not generated_at.empty:
+            generated_time = str(generated_at['created_at'][0])
+        else:
+            generated_time = None
+
+        return (table, generated_time)
 
     def create_history_graph(self, name, file_name):
         """Generate an ADM history graph and save to file"""
@@ -109,6 +115,13 @@ class AdmController:
 
         return systems
 
+    def create_system_adm_from_index(self, system, military: int, industrial: int, strategic: int):
+        """Create a DataFrame for system ADM data from index values"""
+        adm = adm_from_index(military, industrial, strategic)
+
+        return self.create_system_adm(system, adm)
+
+
     def create_system_adm(self, system, adm):
         """Create a DataFrame for system ADM data"""
         system_adm = pd.DataFrame(columns=['system_id', 'adm'])
@@ -119,10 +132,13 @@ class AdmController:
 
         return system_adm
 
-    def get_alliance_structures(self, structures, alliance_id):
+    def get_alliance_structures(self, structures, alliance_id, ignore_tcu):
         """Retrieve a list of alliance sovreignty structures"""
         structure_data = pd.DataFrame.from_dict(structures)
 
+        if ignore_tcu:
+            structure_data = structure_data[structure_data['structure_type_id'] != 32226]
+
         drop_columns = [
             'structure_id',
             'structure_type_id',
@@ -147,10 +163,28 @@ class AdmController:
 
         return True
 
-    def get_system_adms(self, alliance_id):
+    def update_system_adm_from_index(self,
+                                     system_name: str,
+                                     military: int,
+                                     industrial: int,
+                                     strategic: int) -> bool:
+        """Update ADM for system with name from index values"""
+        system = self.database.select_system_with_name(system_name)
+
+        if system.empty:
+            return (False, 0)
+
+        insert_systems = self.create_system_adm_from_index(
+            system, military, industrial, strategic)
+
+        self.database.insert_systems(insert_systems)
+
+        return (True, insert_systems['adm'][0])
+
+    def get_system_adms(self, alliance_id, ignore_tcu):
         """Retrieve ADM for systems controlled by alliance"""
         structures = sovereignty_structures()
-        system_adms = self.get_alliance_structures(structures, alliance_id)
+        system_adms = self.get_alliance_structures(structures, alliance_id, ignore_tcu)
 
         system_adms.drop_duplicates(inplace=True)
 
@@ -170,15 +204,24 @@ class AdmController:
         systems = self.database.select_systems()
         systems.sort_values(by='adm', inplace=True, ascending=True)
 
-        return systems.iloc[0]
+        if not systems.empty:
+            return systems.iloc[0]
+
+        return None
 
     def update_adm_data(self):
         """Update ADM data"""
-        alliance_id = self.configuration.alliance_id
-        system_adms = self.get_system_adms(alliance_id)
+        alliance_id = self.configuration.alliance['id']
+        ignore_tcu = self.configuration.alliance['ignore_tcu']
+        system_adms = self.get_system_adms(alliance_id, ignore_tcu)
 
         self.database.insert_systems(system_adms)
 
+    def purge_adm_records(self, days_old: int):
+        """Purge adm records more than days_old days old"""
+
+        self.database.delete_system_rows(days_old)
+
     def write_file(self, file_name, content) -> bool:
         """Write content to file"""
         with open(file_name, 'w', encoding='UTF-8') as file:
