@@ -1,6 +1,7 @@
-
+"""Thread utility functions"""
 import threading
 
 def run_threaded(function):
+    """Run function in separate thread"""
     job_thread = threading.Thread(target=function)
-    job_thread.start()
\ No newline at end of file
+    job_thread.start()
